@@ -1,34 +1,18 @@
-# This file is part of gnome-tweak-tool.
 # Copyright (c) 2012 Red Hat, Inc.
-#
-# gnome-tweak-tool is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# gnome-tweak-tool is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with gnome-tweak-tool.  If not, see <http://www.gnu.org/licenses/>.
-#
 # Authors:
 #       Rui Matos
+# SPDX-License-Identifier: GPL-3.0+
+# License-Filename: LICENSES/GPL-3.0
 
 import logging
 
 import gi
 gi.require_version("GnomeDesktop", "3.0")
-from gi.repository import Pango, Gtk, GnomeDesktop
-from gtweak.gshellwrapper import GnomeShellFactory
+from gi.repository import Gtk, GnomeDesktop
 from gtweak.tweakmodel import Tweak, TweakGroup
-from gtweak.widgets import GSettingsSwitchTweak, build_label_beside_widget, GSettingsComboEnumTweak, GSettingsComboTweak, build_horizontal_sizegroup, ListBoxTweakGroup, Title
-from gtweak.gsettings import GSettingsSetting, GSettingsMissingError, GSettingsFakeSetting
+from gtweak.widgets import GSettingsSwitchTweak, build_label_beside_widget, GSettingsComboEnumTweak, GSettingsComboTweak, build_horizontal_sizegroup, ListBoxTweakGroup
+from gtweak.gsettings import GSettingsSetting, GSettingsMissingError
 
-_shell = GnomeShellFactory().get_shell()
-_shell_loaded = _shell is not None
 
 class _XkbOption(Gtk.Expander, Tweak):
     def __init__(self, group_id, parent_settings, xkb_info, **options):
@@ -150,12 +134,12 @@ class _XkbOption(Gtk.Expander, Tweak):
         elif active and not w._val in self._values and w._val:
             self._parent_settings.setting_add_to_list(TypingTweakGroup.XKB_GSETTINGS_NAME, w._val)
 
-class TypingTweakGroup(Gtk.Box, TweakGroup):
+class TypingTweakGroup(Gtk.Box):
 
     XKB_GSETTINGS_SCHEMA = "org.gnome.desktop.input-sources"
     XKB_GSETTINGS_NAME = "xkb-options"
     # grp_led is unsupported
-    XKB_OPTIONS_BLACKLIST = {"grp_led"}
+    XKB_OPTIONS_BLACKLIST = {"grp_led", "Compose key"}
 
     def __init__(self):
         Gtk.Box.__init__(self, orientation=Gtk.Orientation.VERTICAL, spacing=3)
@@ -169,7 +153,7 @@ class TypingTweakGroup(Gtk.Box, TweakGroup):
             self.loaded = True
         except GSettingsMissingError:
             logging.info("Typing missing schema %s" % self.XKB_GSETTINGS_SCHEMA)
-            self.loaded = False            
+            self.loaded = False
         except AttributeError:
             logging.warning("Typing missing GnomeDesktop.gir with Xkb support")
             self.loaded = False
@@ -184,7 +168,3 @@ class TypingTweakGroup(Gtk.Box, TweakGroup):
     def _on_changed(self, *args):
         for obj in self._option_objects:
             obj.reload()
-
-TWEAK_GROUPS = [
-    TypingTweakGroup(),
-]
