@@ -1,19 +1,6 @@
-# This file is part of gnome-tweak-tool.
-#
 # Copyright (c) 2011 John Stowers
-#
-# gnome-tweak-tool is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# gnome-tweak-tool is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with gnome-tweak-tool.  If not, see <http://www.gnu.org/licenses/>.
+# SPDX-License-Identifier: GPL-3.0+
+# License-Filename: LICENSES/GPL-3.0
 
 import os.path
 import logging
@@ -308,7 +295,7 @@ class XSettingsOverrides:
 
 class Notification:
     def __init__(self, summary, body):
-        if Notify.is_initted() or Notify.init("GNOME Tweaks"):
+        if Notify.is_initted() or Notify.init(_("GNOME Tweaks")):
             self.notification = Notify.Notification.new(
                                     summary,
                                     body,
